/*******************************************************************************

WePhoto - Photo viewer for multi-touch devices
Copyright (C) 2010 Mihai Paslariu
Original Name MihPhoto
Adapted for WeTab 2011 by Peter Herzog www.pherzog.net

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

*******************************************************************************/

#ifndef __THREAD_SAFE_QUEUE_H__
#define __THREAD_SAFE_QUEUE_H__

#include <QQueue>
#include <QSemaphore>
#include <QMutex>

template<class T> class ThreadSafeQueue : public QQueue<T>
{
private:

	QSemaphore _sem;
	QMutex _mutex;
	
public:
	
	inline void push ( const T& x )
	{
		_mutex.lock();
		QQueue<T>::push_back(x);
		_sem.release();
		_mutex.unlock();
	}

	inline T pop ( )
	{
		T x;
		_sem.acquire();
		_mutex.lock();
		x = QQueue<T>::front();
		QQueue<T>::pop_front();
		_mutex.unlock();

		return x;
	}
};

#endif
