/*******************************************************************************

WePhoto - Photo viewer for multi-touch devices
Copyright (C) 2010 Mihai Paslariu
Original Name MihPhoto
Adapted for WeTab 2011 by Peter Herzog www.pherzog.net

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

*******************************************************************************/

#include <QApplication>
#include <QDir>
#include "Config.h"
#include "MainWindow.h"

void print_console_help( char * appname )
{
	printf("Usage: %s [options] [Datei or Verzeichnisname]\n", appname );
	printf("\nVerfuegbare Optionen:\n");
	printf("%-20s - %s\n", "--fullscreen, -f", "starte im fullscreen mode");
	printf("%-20s - %s\n", "--window", "start in einem Fenster (kein fullscreen)");
	printf("%-20s - %s\n", "--install-dir=<dir>", "hole resource Datei von <dir> anstelle des default Verzeichnisses");
	printf("%-20s - %s\n", "--multitouch, -m", "multitouch support einschalten");
	printf("%-20s - %s\n", "--no-multitouch", "multitouch support ausschalten");
	printf("%-20s - %s\n", "--help, -h", "zeige diese Hilfe");
	printf("%-20s - %s\n", "--version, -v", "zeige die Versionsnummer");

}

void print_console_version( void )
{
	printf("WePhoto - Bildbetrachter für das WeTab\n");
	printf("Copyright (C) 2010 Mihai Paslariu\n");
	printf("Adaptiert für das WeTab von Peter Herzog www.pherzog.net\n");
	printf("Version %.2lf\n", VERSION );
}

int main(int argc, char *argv[])
{
	QApplication app(argc, argv);
	app.addLibraryPath( app.applicationDirPath() );
	g_config.load();

	g_config.install_dir = app.applicationDirPath();
			//+ QDir::separator() + "..";

	QStringList args = app.arguments();
	QString startfile = "";
	bool fullscreen = false;

	for ( int i = 1; i < args.size(); i++ )
	{
		QString v = args[i];
		if ( v == "--fullscreen" || v == "-f" )
			fullscreen = true;
		else if ( v == "--window" )
			fullscreen = false;
		else if ( v.startsWith("--install-dir=") )
			g_config.install_dir = v.mid(14);
		else if ( v == "--multitouch" || v == "-m" )
			g_config.multitouch = true;
		else if ( v == "--no-multitouch" )
			g_config.multitouch = false;
		else if ( v == "--help" || v == "-h" )
		{
			print_console_help(argv[0]);
			return 0;
		} else if ( v == "--version" || v == "-v" ) {
			print_console_version();
			return 0;
		} else
			startfile = v;
	}

	MainWindow window(startfile, fullscreen);
	return app.exec();
}
